@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.12345678';
+our $VERSION = '0.123456789';
 use 5.006;
 use strict;
 use warnings;
@@ -207,6 +207,11 @@ sub raiseError {
 sub graft {
 	my ($self, $name, $json) = @_;
 
+	unless ($json =~ m/[\{\[]/) {
+		$self->{$name} = $json;
+		return $self->{$name};
+	}
+
 	$self->{$name} = eval {
 		$JSON->decode($json);
 	};
@@ -391,7 +396,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.12345678
+Version 0.123456789
 
 =cut
 
