@@ -25,8 +25,8 @@ sub start {
 sub preprocess_req {
         my ($self, $req, $t) = @_;
 	if (!$req) {
+		(my $path = $t->request->uri->path) =~ s/\/$//;
 		if ($self->controllers->{_alias}) {
-			my $path = $t->request->uri->path;
 			for my $candidate (keys %{$self->controllers->{_alias}}) {
                         	my @captured = $path =~ m/$candidate/;
                         	if (scalar @captured) {
@@ -36,7 +36,7 @@ sub preprocess_req {
                 	}
 		}
 		$req = $self->SUPER::preprocess_req($req, $t) if ! $req;
-        	($req) = $t->request->uri->path =~ m/([^\/]+)$/ if ! $req;
+        	($req) = $path =~ m/([^\/]+)$/ if ! $req;
 	}
         return $req;
 }
@@ -51,7 +51,6 @@ sub _build_models {
 	);
 }
 
-
 sub _build_views {
 	my ($self, $pkg, $path, $lib) =@_; 
 	return $self->_load_modules(
@@ -187,7 +186,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.12345678
+Version 0.123456789
 
 =cut
 
